=======
History
=======

1.1.0 (2018-10-29)
------------------

* Documentation improvements.
* Update setup.py to require Python 3.5 or later.
* Converted docs to 'Guzzle' theme.

1.0.0 (2018-10-28)
------------------

* First release on PyPI.
